@@ -4,23 +4,24 @@ from autosteper import AutoSteper
 from autosteper.cage import Cage
 from autosteper.parser import Path_Parser
 
-a_cage = Cage(pristine_path=r'./geom.xyz')
-a_cage.set_workbase(root=r'/home/mkliu/schnet_opt/paper_4_27/10_6')
-
 mach_para = {
-    'batch_type': "Torque",
-    'context_type': "LocalContext",
-    'remote_root': '/home/mkliu/test_dpdispatcher/',
+    'batch_type': "x",
+    'context_type': "SSHContext",
+    'remote_root': 'xx/',
     'remote_profile': {
-        None
+        "hostname": "xx",
+        "username": "xx",
+        "password": "xx",
+        "port": 22,
+        "timeout": 10
     }
 }
 
 resrc_para = {
-    'number_node': 2,
+    'number_node': 6,
     'cpu_per_node': 6,
     'gpu_per_node': 0,
-    'group_size': 5,
+    'group_size': 10,
     'queue_name': "batch",
     'envs': {
         "OMP_STACKSIZE": "4G",
@@ -28,15 +29,18 @@ resrc_para = {
         "OMP_MAX_ACTIVE_LEVELS": "1",
         "MKL_NUM_THREADS": "3"
     },
-    'sub_batch_size': 40
+    'sub_batch_size': 50
 }
 
+a_cage = Cage(pristine_path=r'./geom.xyz')
+a_cage.set_workbase(root=r'xx')
+
 refiner_para = {
     'has_parity': True,
     'cage_size': a_cage.size,
     'refine_top_k': 15,
     'opt_mode': 'xtb',
-    'cmd_list': [r'/home/mkliu/anaconda3/envs/env001/bin/xtb', '--opt', 'tight', '--json'],
+    'cmd_list': [r'xx/xtb', '--opt', 'tight', '--json'],
     'out_list': ['xtbopt.xyz', 'xtbopt.log', 'xtbout.json'],
     'deal_wrong_mode': 'Report',
     'mach_para': mach_para,
@@ -55,7 +59,7 @@ path_para = {
 }
 
 a_path_parser = Path_Parser(path_para=path_para,
-                            dump_root=r'/home/mkliu/schnet_opt/paper_4_27/10_6/parser2_ref',
+                            dump_root=r'xx/parser2_ref',
                             q_cage=a_cage,
                             refiner_para=refiner_para)
 a_path_parser.get_path_info()
