@@ -3,13 +3,13 @@ import os
 from autosteper import AutoSteper
 
 mach_para = {
-        'batch_type': "Torque",
+        'batch_type': "x",
         'context_type': "SSHContext",
-        'remote_root': '/home/mkliu/test_dpdispatcher/',
+        'remote_root': 'xx/',
         'remote_profile': {
-            "hostname": "219.245.39.76",
-            "username": "mkliu",
-            "password": "mkliu123",
+            "hostname": "xx",
+            "username": "xx",
+            "password": "xx",
             "port": 22,
             "timeout": 10
         }
@@ -37,11 +37,11 @@ para = {
     'root': r'./',
     'gen_para': {'group': 'Cl',
                  'geom_mode': 'pre_defined',
-                 'gen_core_path': r'I:\new_nauty\my_v\usenauty\bin\cagesearch.exe'
+                 'gen_core_path': r'xx\cagesearch.exe'
                  },
     'opt_mode': 'xtb',
     'opt_para': {
-        'cmd_list': [r'/home/mkliu/anaconda3/envs/env001/bin/xtb', '--opt', 'tight', '--json'],
+        'cmd_list': [r'xx/xtb', '--opt', 'tight', '--json'],
         'out_list': ['xtbopt.xyz', 'xtbopt.log', 'xtbout.json'],
         'deal_wrong_mode': 'Report',
         'mach_para': mach_para,
